import { polyfillPieElements } from "../response-loader/response-loader";
export const findPie = (pies, element) => (pies && pies.find(pie => pie.modelElementName === element)) || null;
export const findSessionData = (data, id) => (data && data.find(sessionData => sessionData.id === id)) || {};
/**
 * ResponsesService gets all the responses via upsertAggregate function
 * and groups the responses by itemConfig.id,
 * in order to call the aggregates service
 * with proper data (array of responses)
 */
export default class ResponsesService {
    constructor() {
        /**
         * Gets response data and stores it in the appropriate group
         * @param aggregateData: {aggregateId, data, sessionId, score}, where:
         * aggregateId: the key of the group where the response should be added/updated (itemConfig.id)
         * data: the session data
         * sessionId: the session id
         * score: the score for the response
         */
        this.upsertAggregate = aggregateData => {
            const { aggregateId, data, sessionId, score } = aggregateData || {};
            if (!aggregateId)
                return;
            if (!this.questions[aggregateId]) {
                this.questions[aggregateId] = {};
            }
            if (!this.questions[aggregateId][sessionId]) {
                this.questions[aggregateId][sessionId] = {};
            }
            this.questions[aggregateId][sessionId] = {
                data,
                score
            };
        };
        /**
         * Returns aggregate for a specific group
         * @param itemConfig: { models, elements }
         * @param aggregateId: the key of the group
         */
        this.getAggregate = (itemConfig, aggregateId) => {
            try {
                const { models, elements } = itemConfig || {};
                const aggregateGroup = this.questions[aggregateId] || {};
                const sessions = Object.values(aggregateGroup);
                if (!aggregateId || !sessions || !sessions.length || !models || !models.length)
                    return [];
                const pies = polyfillPieElements(elements);
                return models.reduce((acc, model) => {
                    const pie = findPie(pies, model.element);
                    const aggregatorService = pie && window[pie.aggregatorTag];
                    if (!aggregatorService)
                        return acc;
                    return [
                        ...acc,
                        // @ts-ignore
                        aggregatorService.AggregateMap({
                            question: model,
                            responses: sessions.reduce((responsesToModel, { data, score }) => ([
                                ...responsesToModel,
                                { data: findSessionData(data, model.id), score }
                            ]), [])
                        })
                    ];
                }, []);
            }
            catch (e) {
                console.error(e.toString());
                return [];
            }
        };
        this.questions = {};
    }
}
