import { Component, Element, Prop, h } from "@stencil/core";
import { loadResponseElement } from "../../response-loader/response-loader";
/**
 * Renders a user's response to a question in summary text form - not more than 32 characters.
 * This is intended for use in grid/spreadsheet style views.
 *
 * Not all PIE question types may support this feature, in that case no response will be rendered
 * and the attribute `not-available` will be added to the element.
 */
export class PieResponseCell {
    render() {
        var _a;
        this.el.style.margin = '0px';
        if (!this.sessionData || !((_a = this.sessionData) === null || _a === void 0 ? void 0 : _a.itemConfig)) {
            return false;
        }
        const loaded = loadResponseElement("responseCell", this.sessionData, this.el, this.multiPart);
        if (!loaded) {
            return h("slot", { name: "na" });
        }
    }
    static get is() { return "pie-response-cell"; }
    static get properties() { return {
        "sessionData": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [{
                        "text": undefined,
                        "name": "internal"
                    }],
                "text": "The model of the response(s) to render.\nThis will be automatically set it the component is nested within a `pie-live-session` component.\nTODO - fix typing"
            },
            "attribute": "session-data",
            "reflect": false
        },
        "multiPart": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If multi-part items should be supported (render all parts)"
            },
            "attribute": "multi-part",
            "reflect": false
        }
    }; }
    static get contextProps() { return [{
            "name": "doc",
            "context": "document"
        }]; }
    static get elementRef() { return "el"; }
}
