export class Api {
  constructor(token, host) {
    this.token = token;
    this.host = host;
  };

  async createItem(id, config) {
    const query = `
    mutation save($input: ContentItemInput) {  
      importContentItem(input: $input){ 
        id
        version {
          major
          minor
          patch
          prerelease
        }
      }
    }
  `;
    const input = {...{id:id},...{config}}
    const res = await this.executeGql(this.token, query, {input}, this.host);
    return res?.data?.importContentItem;
  }

  async createSession(itemId) {
    const query = `
    mutation createSession($itemId: ID!) {  
      createSession(itemId: $itemId){ 
        id
      }
    }
  `;
    const res = await this.executeGql(this.token, query, {itemId}, this.host);
    return res?.data?.createSession;
  }


  async saveSessionResponse(sessionId, resp) {
    const query = `
    mutation saveResponse($sessionId:ID!, $data: [JSON]) {
      saveSessionResponse(
      id: $sessionId
      data: $data
      date: "${new Date().toISOString()}"
      ) {
        id
      }
    }
    `;

    const sessionValue = JSON.parse(resp);
    delete sessionValue.element;
    const res = await this.executeGql(this.token, query, {sessionId, data:[sessionValue]}, this.host);
    return res?.data?.saveSessionResponse;
  }

   async executeGql(token, query, variables, apiUrl) {
    try {
      const res = await fetch(apiUrl, {
        method: 'POST',
        mode: 'cors',
        headers: {
          'Content-Type': 'application/json',
          'Accept-Encoding': 'gzip, deflate, br',
          Authorization: `Bearer ${token}`,
          Accept: 'application/json'
        },
        body: JSON.stringify({
          query,
          variables
        })
      });
      const jsonBody = await res.json();
      return jsonBody;
    } catch (err) {
      console.error(new Error('error with server request'))
    }
  };
}
