import { Api } from './gql.js';

export class Service {
  constructor() {
    const params = new URLSearchParams(window.location.search);
    const token = params.get('token');
    const host = params.get('host');
    const env = params.get('env') ?? 'qa';

    const liveUrl = params.get('liveUrl');
    const hostUrl = params.get('hostUrl');
    const lazyLoad = params.get('lazyLoad');
    const loadingIndicator = params.get('loadingIndicator');

    this.env = env;
    this.token = token;
    this.host = host;
    this.liveUrl = liveUrl;
    this.hostUrl = hostUrl;
    this.lazyLoad = lazyLoad;
    this.loadingIndicator = loadingIndicator;

    // to test:
    // http://localhost:8080/demo/end-to-end/?
    // host=dev&
    // liveUrl=wss://qa-live.pie-api.com/&
    // hostUrl=https://qa.pie-api.io/services/graphql

    console.log({ env, token, host, liveUrl, hostUrl });
  }

  uuidv4() {
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
      var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);

      return v.toString(16);
    });
  }

  loadPieApiLive(document) {
    if (this.token) {
      const pieApiLive = document.createElement('pie-api-live');

      pieApiLive.token = this.token;

      if (this.liveUrl) {
        pieApiLive.liveUrl = this.liveUrl;
      }

      if (this.hostUrl) {
        pieApiLive.hostUrl = this.hostUrl;
      }

      pieApiLive.host = this.host;

      if (this.lazyLoad) {
        pieApiLive.lazyLoad = this.lazyLoad;
      }

      if (this.loadingIndicator === "false") {
        pieApiLive.loadingIndicator = this.loadingIndicator;
      }

      return pieApiLive;
    } else {
      return null;
    }
  }

  async setupSessions(questions, student) {
    const environmentVariables = {
      dev: 'develop-live.pie-api.com/',
      qa: 'qa-live.pie-api.com/',
      stage: 'stage-live.pie-api.com/',
      prod: 'live.pie-api.com/',
    }

    let url = `https://${environmentVariables.prod}`;

    if (this.host && environmentVariables[this.host]) {
      url = `https://${environmentVariables[this.host]}`;
    }

    if (this.hostUrl) {
      url = this.hostUrl;
    }

    const api = new Api(this.token, url);

    try {
      let sessions = {};

      for (let i = 0; i < questions.length; i++) {
        const mcFetch = await fetch(`/demo/fixtures/${questions[i].element}.json`);
        const mcJson = await mcFetch.json();
        const created = await api.createItem(`pie-live-e23-${questions[i].element}-${this.uuidv4()}`, mcJson);
        const sessionCreated = await api.createSession(created.id);

        sessions[sessionCreated.id] = {
          question: questions[i],
          student: student
        };
      }

      return sessions;
    } catch (e) {
      console.log('\n', { questions, student });
      console.log(e);
      return {};
    }
  }
}

const PieApiService = new Service();

export default PieApiService;
