import { Api } from '../gql.js';


function uuidv4() {
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c) {
    var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);
    return v.toString(16);
  });
}

export function loadPieApiLive(document, token, host) {

  if (token && host) {
    const pieApiLive = document.createElement('pie-api-live');
    pieApiLive.token = token;
    pieApiLive.host = host;
    return pieApiLive;
  } else {
    return null;
  }
}

export async function setupMockItems(token, host, pieType) {
  const api = new Api(token, host);

    const mcFetch = await fetch(`/demo/fixtures/${pieType}.json`);
    const mcJson = await mcFetch.json();
  const created = await api.createItem(`pie-live-e23-${pieType}-${uuidv4()}`, mcJson);
    const sessionCreated = await api.createSession(created.id);

    return [sessionCreated];
}

export async function setupSessions(token, host, questions, student) {
  const api = new Api(token, host);

  try {
    let sessions = {};

    for (let i = 0; i < questions.length; i++) {
      const mcFetch = await fetch(`/demo/fixtures/${questions[i].element}.json`);
      const mcJson = await mcFetch.json();
      const created = await api.createItem(`pie-live-e23-${questions[i].element}-${uuidv4()}`, mcJson);
      const sessionCreated = await api.createSession(created.id);

      sessions[sessionCreated.id] = {
        question: questions[i],
        student: student
      };
    }

    return sessions;
  } catch (e) {
    console.log('\n', { questions, student });
    console.log(e);
    return {};
  }
}


export async function setupMockItem(token, host, question, student) {
  const api = new Api(token, host);

  try {
    let sessions = [];

    const mcFetch = await fetch(`/demo/fixtures/${question.element}.json`);
    const mcJson = await mcFetch.json();
    const created = await api.createItem(`pie-live-e23-${question.element}-${student.id}`, mcJson);
    const sessionCreated = await api.createSession(created.id);

    sessions.push({
      sessionId: sessionCreated.id,
      question,
      student
    });

    console.log({ sessions});
    return sessions;
  } catch (e) {
    console.log('\n', { question, student });
    console.log(e);
    return [];
  }
}


export async function loadResponse(pieType) {
  const resFetch = await fetch(`/demo/fixtures/${pieType}-response.json`);
  const resJson = await resFetch.json();
  return JSON.stringify(resJson, null, '  ');
}

export async function saveResponse(token, host, sessionId, data) {
  const api = new Api(token, host);
  const res = await api.saveSessionResponse(sessionId, data);
  return res;
}
