import PieApiService from './index.js';
import { createExpandToSeeMoreDetails, students, questions } from './utils.js';

const populateStudentsContainer = ({ question, allSessions }) => {
  const container = document.querySelector('#students-container');

  container.innerHTML = '';

  // for each student add an item in the students container
  students.forEach(student => {
      const studentItem = document.createElement('div');
      const studentItemTitle = document.createElement('div');

      studentItem.classList.add('student-item');
      studentItem.id = `student-${student.id}-${question.element}-${question.id}`;

      // set student name as title
      studentItemTitle.innerText = student.name;

      studentItem.appendChild(studentItemTitle);
      container.appendChild(studentItem);
    }
  );

  const sessionsIds = Object.keys(allSessions);
  const sessions = sessionsIds
    .filter(sessionKey => {
      const { question: q } = allSessions[sessionKey] || {};
      const sameId = q.id === question.id;
      const sameElement = q.element === question.element;

      return sameId && sameElement;
    });

  sessions.forEach((sessionId) => {
    const { student } = allSessions[sessionId];
    const studentItem = document.querySelector(`#student-${student.id}-${question.element}-${question.id}`);

    // load live session and player for item session
    const ls = document.createElement('pie-live-session');
    ls.sessionId = sessionId;

    const response = document.createElement('pie-response');

    createExpandToSeeMoreDetails(response);

    ls.appendChild(response);
    studentItem.appendChild(ls);
  });
};

export async function loadQuestionsView({ allSessions }) {
  // create pie-api-live and add it to teacher view
  const pieApiLive = PieApiService.loadPieApiLive(document);

  // populate side menu
  const sideMenu = document.createElement('div');
  sideMenu.classList.add('side-menu');

  // for each question type, add a new item to the side menu
  questions.forEach((question, index) => {
    const sideMenuItem = document.createElement('div');

    sideMenuItem.classList.add('side-menu-item');
    sideMenuItem.innerHTML = `<h4>Q${index}</h4><span>${question.element}-${question.id}</span>`;

    sideMenuItem.setAttribute('questionId', question.id);
    sideMenuItem.setAttribute('questionElement', question.element);
    sideMenuItem.onclick = () => {
      populateStudentsContainer({ question, allSessions });

      // remove side-menu-selected class from the previously selected question
      const previouslySelected = document.querySelector('.side-menu-selected');

      if (previouslySelected) {
        previouslySelected.classList.remove('side-menu-selected');
      }

      // add side-menu-selected class to the currently selected question
      sideMenuItem.classList.add('side-menu-selected');
    }

    sideMenu.appendChild(sideMenuItem);
  });

  // prepare students container
  const studentsContainer = document.createElement('div');
  const teacherView = document.querySelector('#teacher-view');

  studentsContainer.id = 'students-container';

  // append side menu to teacher view
  teacherView.appendChild(sideMenu);
  // append students container in pie-api-live
  pieApiLive.appendChild(studentsContainer);
  // and pie-api-live to teacher view
  teacherView.appendChild(pieApiLive);
}
