import PieApiService from './index.js';
import { students, questions } from './utils.js';

const createTableHeader = (pieApiLive) => {
  // create table's header
  const row = document.createElement('tr');
  row.id = 'table-header';

  const initialColumn = document.createElement('td');
  const initialTitle = document.createElement('div');

  initialTitle.innerText = 'Students\\Questions';
  initialColumn.appendChild(initialTitle);
  row.appendChild(initialColumn);

  questions.forEach((question, index) => {
    const questionColumn = document.createElement('td');
    const questionTitle = document.createElement('div');
    questionTitle.classList.add('question-title');

    questionColumn.id = `question-${question.element}-${question.id}`;
    questionTitle.innerHTML = `<h3>Q${index}</h3><span>${question.element}-${question.id}</span>`;

    questionColumn.appendChild(questionTitle);
    row.appendChild(questionColumn);
  });

  pieApiLive.appendChild(row);
};

export async function loadStudentsView({ allSessions }) {
  const pieApiLive = PieApiService.loadPieApiLive(document);

  // get teacher view and append the new created pie api live
  const teacherView = document.querySelector('#teacher-view');
  teacherView.appendChild(pieApiLive);

  // create table header
  createTableHeader(pieApiLive);

  // create table
  students.forEach(student => {
    // create a row for each student
    const row = document.createElement('tr');
    row.id = `student-${student.id}`;

    // create row's first column (student's name)
    const studentName = document.createElement('td');

    studentName.innerText = student.name;
    row.appendChild(studentName);

    // create a column for each question
    questions.forEach(question => {
      const questionColumn = document.createElement('td');

      questionColumn.id = `question-${student.id}-${question.element}-${question.id}`;

      row.appendChild(questionColumn);
      pieApiLive.appendChild(row);
    });
  });

  // set pie-live-sessions
  const sessions = Object.keys(allSessions);

  sessions.forEach((sessionId) => {
    const session = allSessions[sessionId];
    const { question, student } = session;

    const questionColumn = document.querySelector(`#question-${student.id}-${question.element}-${question.id}`);

  // <item-metadata key="kds_item_type" attribute="item-type">
    const IM = document.createElement('item-metadata');
    IM.setAttribute('key', "isRelease");
    IM.setAttribute('attribute', "test");

    const IM3 = document.createElement('item-metadata');
    IM3.setAttribute('key', "id");
    IM3.setAttribute('attribute', "the-id");

    // load live session and player for item session
    const ls = document.createElement('pie-live-session');
    ls.sessionId = sessionId;

    const responseCell = document.createElement('pie-response-cell');

    ls.appendChild(responseCell);
    questionColumn.appendChild(IM);
    questionColumn.appendChild(IM3);
    questionColumn.appendChild(ls);
  });
}
