export const loadSessionContentItem = async (token, id, apiUrl, metadata) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    const output = {};
    const query = `
    query sessionItem($id: ID!) {
        contentItemSession(id: $id) {
            contentItem {
                id
                config
              }
              data
        }
        scoreSession(id: $id, env: {}, virtualController: true) {
          points
          max
          type
          partialScoring
        }
    }
  `;
    const res = await executeGql(token, query, { id }, apiUrl);
    output.config = (_c = (_b = (_a = res === null || res === void 0 ? void 0 : res.data) === null || _a === void 0 ? void 0 : _a.contentItemSession) === null || _b === void 0 ? void 0 : _b.contentItem) === null || _c === void 0 ? void 0 : _c.config;
    output.data = (_e = (_d = res === null || res === void 0 ? void 0 : res.data) === null || _d === void 0 ? void 0 : _d.contentItemSession) === null || _e === void 0 ? void 0 : _e.data;
    output.timestamp = (_h = (_g = (_f = res === null || res === void 0 ? void 0 : res.data) === null || _f === void 0 ? void 0 : _f.contentItemSession) === null || _g === void 0 ? void 0 : _g.contentItem) === null || _h === void 0 ? void 0 : _h.timestamp;
    output.score = (_j = res === null || res === void 0 ? void 0 : res.data) === null || _j === void 0 ? void 0 : _j.scoreSession;
    if (metadata && metadata.length > 0 && ((_l = (_k = res === null || res === void 0 ? void 0 : res.data) === null || _k === void 0 ? void 0 : _k.contentItemSession) === null || _l === void 0 ? void 0 : _l.contentItem)) {
        const itemId = res.data.contentItemSession.contentItem.id;
        if (itemId) {
            const mdQuery = `
        query metadata($id: VersionedID!) {
          contentItemMetaData(id: $id) {
            ${metadata.map(m => m.key).join(' ')}
          }
        }
      `;
            const mdRes = await executeGql(token, mdQuery, { id: itemId }, apiUrl);
            if ((_m = mdRes === null || mdRes === void 0 ? void 0 : mdRes.data) === null || _m === void 0 ? void 0 : _m.contentItemMetaData) {
                output.metadata = mdRes.data.contentItemMetaData;
            }
        }
    }
    return output;
};
const executeGql = async (token, query, variables, apiUrl) => {
    try {
        const res = await fetch(apiUrl, {
            method: 'POST',
            mode: 'cors',
            headers: {
                'Content-Type': 'application/json',
                'Accept-Encoding': 'gzip, deflate, br',
                Authorization: `Bearer ${token}`,
                Accept: 'application/json',
            },
            body: JSON.stringify({
                query,
                variables,
            }),
        });
        return await res.json();
    }
    catch (err) {
        throw new Error('error with server request');
    }
};
export const loadAssignmentSessions = async (token, assignmentId, sessionOpts, apiUrl) => {
    var _a;
    const query = `
  query Query($assignmentId: ID!, $opts: PaginationOptions) {
  assignment(id: $assignmentId) {
    sessions(opts: $opts) {
      docs {
        id
        data
        autoScore
        createdAt
        manualScore
        mode
        updatedAt
        item {
          id
        }
      }
      cursor {
        next
        previous
      }
  }
}
}`;
    try {
        const res = await executeGql(token, query, { assignmentId, opts: sessionOpts }, apiUrl);
        return (_a = res === null || res === void 0 ? void 0 : res.data) === null || _a === void 0 ? void 0 : _a.assignment;
    }
    catch (e) {
        console.error(e);
    }
};
export const loadAssignmentItems = async (token, assignmentId, itemOpts, apiUrl) => {
    var _a;
    const query = `
  query Query($assignmentId: ID!, $opts: PaginationOptions) {
  assignment(id: $assignmentId) {
    items(opts: $opts) {
      docs {
        id
        name
        config
        version {
          major
          minor
          patch
          prerelease
        }
      }
      cursor {
        next
        previous
      }
     }
  }
}`;
    try {
        const res = await executeGql(token, query, { assignmentId, opts: itemOpts }, apiUrl);
        return (_a = res === null || res === void 0 ? void 0 : res.data) === null || _a === void 0 ? void 0 : _a.assignment;
    }
    catch (e) {
        console.error(e);
    }
};
