export const tagMap = {
    "@pie-element/calculator": 'calculator',
    "@pie-element/categorize": 'categorize',
    "@pie-element/charting": 'charting',
    "@pie-element/explicit-constructed-response": 'explicit-constructed-response',
    "@pie-element/drag-in-the-blank": 'drag-in-the-blank',
    "@pie-element/drawing-response": 'drawing-response',
    "@pie-element/ebsr": 'ebsr',
    "@pie-element/extended-text-entry": 'extended-text-entry',
    "@pie-element/graphing": 'graphing',
    "@pie-element/hotspot": 'hotspot',
    "@pie-element/inline-dropdown": 'inline-dropdown',
    "@pie-element/match": 'match',
    "@pie-element/match-list": 'match-list',
    "@pie-element/math-inline": 'math-inline',
    "@pie-element/multiple-choice": 'multiple-choice',
    "@pie-element/number-line": 'number-line',
    "@pie-element/passage": 'passage',
    "@pie-element/placement-ordering": 'placement-ordering',
    "@pie-element/protractor": 'protractor',
    "@pie-element/rubric": 'rubric',
    "@pie-element/ruler": 'ruler',
    "@pie-element/select-text": 'select-text',
};
export const aggregatorTagMap = {
    "@pie-element/calculator": 'calculator-aggregator',
    "@pie-element/categorize": 'categorize-aggregator',
    "@pie-element/charting": 'charting-aggregator',
    "@pie-element/explicit-constructed-response": 'explicit-constructed-response-aggregator',
    "@pie-element/drag-in-the-blank": 'drag-in-the-blank-aggregator',
    "@pie-element/drawing-response": 'drawing-response-aggregator',
    "@pie-element/ebsr": 'ebsr-aggregator',
    "@pie-element/extended-text-entry": 'extended-text-entry-aggregator',
    "@pie-element/graphing": 'graphing-aggregator',
    "@pie-element/hotspot": 'hotspot-aggregator',
    "@pie-element/inline-dropdown": 'inline-dropdown-aggregator',
    "@pie-element/match": 'match-aggregator',
    "@pie-element/match-list": 'match-list-aggregator',
    "@pie-element/math-inline": 'math-inline-aggregator',
    "@pie-element/multiple-choice": 'multiple-choice-aggregator',
    "@pie-element/number-line": 'number-line-aggregator',
    "@pie-element/passage": 'passage-aggregator',
    "@pie-element/placement-ordering": 'placement-ordering-aggregator',
    "@pie-element/protractor": 'protractor-aggregator',
    "@pie-element/rubric": 'rubric-aggregator',
    "@pie-element/ruler": 'ruler-aggregator',
    "@pie-element/select-text": 'select-text-aggregator',
};
export const parsePackage = (input) => {
    const RE_SCOPED = /^(@[^/]+\/[^/@]+)(?:\/([^@]+))?(?:@([\s\S]+))?/;
    const RE_NORMAL = /^([^/@]+)(?:\/([^@]+))?(?:@([\s\S]+))?/;
    if (typeof input !== 'string') {
        throw new TypeError('Expected a string');
    }
    const matched = input.charAt(0) === '@' ? input.match(RE_SCOPED) : input.match(RE_NORMAL);
    if (!matched) {
        throw new Error(`[parse-package-name] "${input}" is not a valid string`);
    }
    return {
        name: matched[1],
        path: matched[2] || '',
        version: matched[3] || ''
    };
};
// import the cdn at runtime using a fallback in case somethig goes wrong
export const importWithFallback = (primaryUrl) => {
    let fallbackUrl = primaryUrl.replace('unpkg.com', 'cdn.jsdelivr.net/npm');
    return import(primaryUrl)
        .catch(error => {
        console.error(`Failed to load module from ${primaryUrl}:`, error);
        if (fallbackUrl) {
            console.log(`Attempting to load from fallback URL: ${fallbackUrl}`);
            return import(fallbackUrl);
        }
        throw new Error(`Both primary and fallback URLs failed for ${primaryUrl}`);
    });
};
