import { r as registerInstance, h, g as getElement } from './index-61a21509.js';
import { i as importWithFallback, b as parsePackage, t as tagMap, p as pieElementExtensionsUrl } from './constants-fd932faf.js';

const pieAggregatesMapping = {
    "@pie-element/categorize": {
        aggregate: `${pieElementExtensionsUrl}/CategorizeAggregate.js`,
    },
    "@pie-element/charting": {
        aggregate: `${pieElementExtensionsUrl}/ChartingAggregate.js`,
    },
    "@pie-element/explicit-constructed-response": {
        aggregate: `${pieElementExtensionsUrl}/ConstructedAggregate.js`,
    },
    "@pie-element/drag-in-the-blank": {
        aggregate: `${pieElementExtensionsUrl}/DragInTheBlankAggregate.js`,
    },
    "@pie-element/drawing-response": {
        aggregate: `${pieElementExtensionsUrl}/DrawingAggregate.js`,
    },
    "@pie-element/ebsr": {
        aggregate: `${pieElementExtensionsUrl}/EBSRAggregate.js`,
    },
    "@pie-element/extended-text-entry": {
        aggregate: `${pieElementExtensionsUrl}/ExtendedTextEntryAggregate.js`,
    },
    "@pie-element/graphing": {
        aggregate: `${pieElementExtensionsUrl}/GraphingAggregate.js`,
    },
    "@pie-element/hotspot": {
        aggregate: `${pieElementExtensionsUrl}/HotspotAggregate.js`,
    },
    "@pie-element/inline-dropdown": {
        aggregate: `${pieElementExtensionsUrl}/InlineDropdownAggregate.js`,
    },
    "@pie-element/match": {
        aggregate: `${pieElementExtensionsUrl}/MatchAggregate.js`,
    },
    "@pie-element/match-list": {
        aggregate: `${pieElementExtensionsUrl}/MatchListAggregate.js`,
    },
    "@pie-element/math-inline": {
        aggregate: `${pieElementExtensionsUrl}/MathInlineAggregate.js`,
    },
    "@pie-element/multiple-choice": {
        aggregate: `${pieElementExtensionsUrl}/MultipleChoiceAggregate.js`,
    },
    "@pie-element/number-line": {
        aggregate: `${pieElementExtensionsUrl}/NumberLineAggregate.js`,
    },
    "@pie-element/placement-ordering": {
        aggregate: `${pieElementExtensionsUrl}/OrderingAggregate.js`,
    },
    "@pie-element/select-text": {
        aggregate: `${pieElementExtensionsUrl}/SelectTextAggregate.js`,
    },
    "@pie-element/image-cloze-association": {
        aggregate: `${pieElementExtensionsUrl}/ImageClozeAssociationAggregate.js`,
    },
};
const pieAggregatesBlackList = {
    "@pie-element/calculator": true,
    "@pie-element/passage": true,
    "@pie-element/protractor": true,
    "@pie-element/rubric": true,
    "@pie-element/ruler": true,
};
/**
 * @param elements the elements definitions
 */
const polyfillPieAggregates = (elements) => {
    if (elements) {
        const pieDefs = Object.keys(elements).map(tag => {
            const { name } = parsePackage(elements[tag]);
            return Object.assign({
                elements: pieAggregatesMapping[name],
                blackListed: pieAggregatesBlackList[name] === true
            }, { tag: tagMap[name], 
                // we have to keep the used tag name to determine if the item can be rendered (check loadAggregateElement) in case of multi-part
                modelElementName: tag });
        });
        return pieDefs;
    }
};
const loadAggregateElement = (elementName, aggregateData, host) => {
    if (!aggregateData || !(aggregateData === null || aggregateData === void 0 ? void 0 : aggregateData.itemConfig) || !(aggregateData === null || aggregateData === void 0 ? void 0 : aggregateData.aggregate)) {
        return false;
    }
    const pieAggregateConfig = aggregateData.itemConfig.pie ? aggregateData.itemConfig.pie : aggregateData.itemConfig;
    if (!pieAggregateConfig.aggregatePies) {
        pieAggregateConfig.aggregatePies = polyfillPieAggregates(pieAggregateConfig.elements);
    }
    const hostShadowRoot = host.shadowRoot;
    if (!hostShadowRoot)
        return;
    host.shadowRoot.innerHTML = "";
    pieAggregateConfig.aggregatePies && pieAggregateConfig.aggregatePies.forEach((pie) => {
        var _a;
        let elementSpecifier = ((_a = pie.elements) !== null && _a !== void 0 ? _a : {})[elementName];
        const tag = `${pie.tag}-${elementName}`.toLowerCase();
        const { blackListed } = pie;
        if (elementSpecifier) {
            customElements.whenDefined(tag).then(() => {
                var _a;
                (_a = aggregateData.itemConfig) === null || _a === void 0 ? void 0 : _a.models.forEach(m => {
                    if (m.element == pie.modelElementName && !blackListed) {
                        let el = host.shadowRoot.querySelector(`${tag}[id="${m.id}"]`);
                        if (!el) {
                            const newEl = document.createElement(tag);
                            newEl.setAttribute('id', m.id);
                            host.shadowRoot.appendChild(newEl);
                            el = newEl;
                        }
                        el.model = m;
                        el.aggregate = aggregateData === null || aggregateData === void 0 ? void 0 : aggregateData.aggregate;
                    }
                });
            });
            if (!customElements.get(tag)) {
                importWithFallback(elementSpecifier).then(Module => {
                    if (!customElements.get(tag)) {
                        customElements.define(tag, Module.default);
                    }
                }).catch(err => {
                    console.error(err.toString());
                });
            }
        }
        else if (blackListed) {
            let el = host.shadowRoot.querySelector('pre');
            if (!el) {
                const newEl = document.createElement('pre');
                host.shadowRoot.appendChild(newEl);
                el = newEl;
            }
            el.textContent = 'No Aggregate Available ';
        }
        else {
            // just for test purpose
            let el = host.shadowRoot.querySelector('pre');
            if (!el) {
                const newEl = document.createElement('pre');
                host.shadowRoot.appendChild(newEl);
                el = newEl;
            }
            el.textContent = JSON.stringify(aggregateData === null || aggregateData === void 0 ? void 0 : aggregateData.aggregate, undefined, 2);
        }
    });
    return;
};

class PieAggregate {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.aggregateData = { loaded: false };
    }
    watchAggregateId() {
    }
    watchAggregateData() {
    }
    itemAggregateHandler(event) {
        if (event.detail.aggregateId === this.aggregateId) {
            this.aggregateData = event.detail;
            this.aggregateData.loaded = true;
        }
    }
    render() {
        loadAggregateElement("aggregate", this.aggregateData, this.el);
        return (h("div", null, "Aggregate"));
    }
    get el() { return getElement(this); }
    static get watchers() { return {
        "aggregateId": ["watchAggregateId"],
        "aggregateData": ["watchAggregateData"]
    }; }
}

export { PieAggregate as pie_aggregate };
