import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-61a21509.js';

class PieLiveSession {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.updateItemInfoInProgress = true;
        this.sessionData = { loaded: false };
        this.emitUpdateAggregate = () => {
            if (this.aggregateId) {
                this.updateAggregate.emit({
                    data: this.sessionData.data,
                    score: this.sessionData.score,
                    aggregateId: this.aggregateId,
                    itemConfig: this.itemConfig,
                    sessionId: this.sessionId
                });
            }
        };
        this.emitAttachSession = () => {
            this.attachSession.emit(this.sessionId);
        };
        this.emitEventReceived = () => {
            this.eventReceived.emit(this.sessionData);
        };
        this.attachSession = createEvent(this, "attachSession", 7);
        this.eventReceived = createEvent(this, "eventReceived", 7);
        this.updateAggregate = createEvent(this, "updateAggregate", 7);
        this.startSubscription = createEvent(this, "startSubscription", 7);
    }
    watchSessionId(newSessionId, oldSessionId) {
        if (newSessionId && (newSessionId !== oldSessionId)) {
            this.itemConfig = null;
            this.updateItemInfoInProgress = true;
            this.emitAttachSession();
            this.emitStartSubscription();
        }
    }
    watchAggregateId(aggId) {
        this.aggregateId = aggId;
        this.emitUpdateAggregate();
    }
    watchItemAndSessionData(newVal) {
        const { item, session } = newVal || {};
        this.itemConfig = item === null || item === void 0 ? void 0 : item.config;
        this.metadataValues = item === null || item === void 0 ? void 0 : item.searchMetaData;
        const { createdAt, score, id, manualScore, autoScore } = session || {};
        if (session && this.sessionDataIsValid(createdAt)) {
            this.sessionData = Object.assign(Object.assign(Object.assign({}, this.sessionData), session), { loaded: true, sessionId: id, score: score || manualScore || autoScore || undefined, itemConfig: this.itemConfig });
            this.emitUpdateAggregate();
        }
        this.emitEventReceived();
        this.updateItemInfoInProgress = false;
    }
    sessionDataIsValid(timestamp) {
        var _a;
        if (!timestamp) {
            console.error(`no createdAt returned for event`);
            return false;
        }
        return !(new Date(timestamp) <= new Date((_a = this.sessionData) === null || _a === void 0 ? void 0 : _a.timestamp));
    }
    getCorrectness(points, maxPoints) {
        if (!maxPoints)
            return null;
        if (points === maxPoints)
            return 'correct';
        if (points === 0)
            return 'incorrect';
        if (points > 0 && points < maxPoints)
            return 'partial';
    }
    async componentWillLoad() {
        if (this.sessionId) {
            this.emitAttachSession();
        }
    }
    componentDidLoad() {
        const element = this.el;
        if (element) {
            this.emitStartSubscription();
        }
    }
    emitStartSubscription() {
        if (this.sessionId) {
            this.startSubscription.emit({ sessionId: this.sessionId });
        }
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q;
        const cells = this.el.querySelectorAll('pie-response-cell');
        const responses = this.el.querySelectorAll('pie-response');
        const cell = cells[0];
        const response = responses[0];
        const metadataAttributes = {};
        cell && (cell.sessionData = this.sessionData);
        response && (response.sessionData = this.sessionData);
        if ((cells === null || cells === void 0 ? void 0 : cells.length) > 1 || (responses === null || responses === void 0 ? void 0 : responses.length) > 1) {
            // TODO this is temporary, until multi-part is figured out
            throw (new Error('only one pie-response / pie-response-cell may be included within a pie-live-session element'));
        }
        if (this.metadataValues) {
            (_a = this.metadata) === null || _a === void 0 ? void 0 : _a.forEach(m => {
                metadataAttributes[m.attribute] = this.metadataValues[m.key];
            });
        }
        if (this.updateItemInfoInProgress && this.loadingIndicator) {
            return h("loading-indicator", null);
        }
        return (h(Host, Object.assign({ loaded: ((_b = this.sessionData) === null || _b === void 0 ? void 0 : _b.loaded) ? 'true' : 'false', "updated-at": (_c = this.sessionData) === null || _c === void 0 ? void 0 : _c.timestamp, "session-id": this.sessionId, "aggregate-id": this.aggregateId, "score-type": (_e = (_d = this.sessionData) === null || _d === void 0 ? void 0 : _d.score) === null || _e === void 0 ? void 0 : _e.type, points: (_g = (_f = this.sessionData) === null || _f === void 0 ? void 0 : _f.score) === null || _g === void 0 ? void 0 : _g.points, max: (_j = (_h = this.sessionData) === null || _h === void 0 ? void 0 : _h.score) === null || _j === void 0 ? void 0 : _j.max, "partial-scoring": String((_l = (_k = this.sessionData) === null || _k === void 0 ? void 0 : _k.score) === null || _l === void 0 ? void 0 : _l.partialScoring), correctness: this.getCorrectness((_o = (_m = this.sessionData) === null || _m === void 0 ? void 0 : _m.score) === null || _o === void 0 ? void 0 : _o.points, (_q = (_p = this.sessionData) === null || _p === void 0 ? void 0 : _p.score) === null || _q === void 0 ? void 0 : _q.max) }, metadataAttributes), h("slot", null)));
    }
    get el() { return getElement(this); }
    static get watchers() { return {
        "sessionId": ["watchSessionId"],
        "aggregateId": ["watchAggregateId"],
        "_itemAndSessionData": ["watchItemAndSessionData"]
    }; }
}

export { PieLiveSession as pie_live_session };
