import { EventEmitter } from "../../stencil-public-runtime";
import { ApolloClient } from '@apollo/client';
import { MetadataProperty } from '../../types';
export declare class PieApiLive {
    gqlClient: ApolloClient<any>;
    private responsesService;
    /**
     * The api token for pie-api.
     * The token must have the `live` scope.
     */
    token: string;
    /**
     * The pie-api-live host (environment) - used to determine live (subscriptions) hosts.
     * One of: `dev`, `prod`.
     *
     * e.g.: if host = 'dev' => webSocket connection to wss://live.dev.pie-api.com/api/graphql
     */
    host: string;
    /**
     * The live server CUSTOM host. If present, overrides the live (subscriptions) server host.
     *
     * e.g.: `wss://live.dev.pie-api.com/api/graphql
     *
     * @internal
     */
    liveUrl: string;
    pageSize: number;
    /**
     *  The Assignment ID - REQUIRED in order to load any data
     */
    assignmentId: string;
    /**
     * If loading indicator should show up while the item is loading.
     */
    loadingIndicator: boolean;
    /**
     * An array of MetadataProperties to be extracted from Item and added to `pie-live-session` elements as attributes.
     * If no value is found for the provided key on an item, the attribute will not be set.
     * This property must be set before adding any child `<pie-live-session>` elements.
     *
     * [
     *   {
     *     key:"metadata_key",
     *     attribute: "attribute-name"
     *   }
     * ]
     *
     * This property can alternatively be set declaritively in html using `<item-metadata key="foo" attribute-name="foo-value">` as a child
     * element of `<pie-api-live>` before any `<pie-live-session>` elements.
     */
    metadata: MetadataProperty[];
    /**
     * Boolean that determines if aggregates have to be calculated and emitted
     */
    emitAggregates: boolean;
    /**
     * Emitted when an aggregate has been recalculated
     */
    itemAggregate: EventEmitter;
    /**
     * Emitted when there's a new item in the assignment
     */
    newItemInAssignment: EventEmitter;
    /**
     * Emitted when there's a new session in the assignment
     */
    newSessionInAssignment: EventEmitter;
    /** Subscription to watch sessions */
    _subscriptionForSessions: any;
    /** Subscription to watch items */
    _subscriptionForItems: any;
    /**
     *  Used to store targets to all pie-live-sessions in order to be able to pass proper data
     */
    _mapSessionIdsToSessionTargets: Object;
    /** Used to store all the items that were received via watchAssignmentItems */
    _items: any;
    /** Used to store all the sessions that were received via watchAssignmentSessions */
    _sessions: any;
    /** Used to map the sessions with proper items */
    _mapSessionIdsToItemIds: any;
    watchChange(): void;
    watchMetadata(newVal: any, oldVal: any): void;
    watchAssignmentId(newVal: any, oldVal: any): void;
    setItemAndSession: (target: any, session: any, item: any) => void;
    setItemAndSessionData: (sessionId: any) => void;
    getAssignmentSessionsAndItems: () => Promise<void>;
    parseSession: (session: any) => void;
    parseItem: (item: any) => void;
    loadAllAssignmentItems: (token: string, assignmentId: string, itemOpts: any, apiUrl: any) => Promise<any[]>;
    loadAllAssignmentSessions: (token: string, assignmentId: string, sessionOpts: any, apiUrl: any) => Promise<any[]>;
    subscribeAssignmentSessions: () => void;
    subscribeAssignmentItems: () => void;
    loadAssignment: () => void;
    connectedCallback(): void;
    disconnectedCallback(): Promise<void>;
    addSessionId: (event: any) => void;
    handleStartSubscription(event: CustomEvent): void;
    handleLiveSessionAdded(ev: Event): void;
    calculateAndEmitAggregate(detail: any): Promise<void>;
    handleUpdateAggregate(event: CustomEvent): Promise<void>;
    initClient(): void;
    render(): any;
}
