import { EventEmitter } from '../../stencil-public-runtime';
import { MetadataProperty } from '../../types';
declare type SessionData = {
    loaded: boolean;
    savedCount?: number;
    timestamp?: Date;
    score?: any;
    data?: Object;
    itemConfig?: Object;
};
export declare class PieLiveSession {
    itemConfig: any;
    metadataValues: any;
    updateItemInfoInProgress: boolean;
    el: HTMLElement;
    sessionData: SessionData;
    /**
     * The Item Session Id to watch
     */
    sessionId: string;
    /**
     * The Aggregate Id to use
     */
    aggregateId: string;
    /**
     * If loading indicator should show up while the item is loading
     */
    loadingIndicator: boolean;
    /**
     * An array of MetadataProperties to be extracted from Item and added to `pie-live-session` elements as attributes.
     * If no value is found for the provided key on an item, the attribute will not be set.
     * @internal
     */
    metadata: MetadataProperty[];
    /**
     * Used to set itemConfig and sessionData
     * @internal
     */
    _itemAndSessionData: string;
    /**
     * Emitted when the element is first connected to the DOM.
     */
    attachSession: EventEmitter;
    /**
     * Emitted when an event has been received for this session.
     */
    eventReceived: EventEmitter;
    /**
     * Emitted when session data changed (used for aggregates)
     * @internal
     */
    updateAggregate: EventEmitter;
    /**
     * Emitted when session should be added in the subscriptions queue
     * @internal
     */
    startSubscription: EventEmitter;
    watchSessionId(newSessionId: any, oldSessionId: any): void;
    watchAggregateId(aggId: any): void;
    watchItemAndSessionData(newVal: any): void;
    sessionDataIsValid(timestamp: any): boolean;
    getCorrectness(points: any, maxPoints: any): "correct" | "incorrect" | "partial";
    componentWillLoad(): Promise<void>;
    componentDidLoad(): void;
    emitUpdateAggregate: () => void;
    emitAttachSession: () => void;
    emitEventReceived: () => void;
    emitStartSubscription(): void;
    render(): any;
}
export {};
