export declare type MetadataProperty = {
    key: string;
    attribute: string;
};
export interface SessionEvent {
    type: SessionEventType;
    timestamp: Date;
}
export declare enum SessionEventType {
    SAVE = "save",
    LOAD = "load",
    MODEL = "model",
    SCORE = "score",
    MANUAL_SCORE = "manual-score"
}
export declare class LoadSessionEvent implements SessionEvent {
    readonly timestamp: Date;
    type: SessionEventType;
    constructor(timestamp: Date);
}
export declare class SaveSessionEvent implements SessionEvent {
    readonly timestamp: Date;
    readonly data: any[];
    type: SessionEventType;
    constructor(timestamp: Date, data: any[], _source?: string);
}
export declare class ModelEvent implements SessionEvent {
    readonly timestamp: Date;
    readonly env: {
        mode: "gather" | "view" | "evaluate";
    };
    type: SessionEventType;
    constructor(timestamp: Date, env: {
        mode: "gather" | "view" | "evaluate";
    });
}
export declare class ManualScoreEvent implements SessionEvent {
    readonly timestamp: Date;
    readonly score: ManualScore;
    type: SessionEventType;
    constructor(timestamp: Date, score: ManualScore);
}
export declare class ScoreEvent implements SessionEvent {
    readonly timestamp: Date;
    readonly score: AutoScore;
    readonly mode: Mode;
    type: SessionEventType;
    constructor(timestamp: Date, score: AutoScore, mode?: Mode);
}
export declare enum ScoreType {
    AUTO = "auto",
    MANUAL = "manual"
}
export interface SessionScore {
    points: number;
    max: number;
    type?: ScoreType;
}
export interface ManualScore extends SessionScore {
}
export interface AutoScore extends SessionScore {
    elements?: any[];
    partialScoring: boolean;
}
export interface NoManualScore {
    message: string;
}
export declare type Mode = "gather" | "view" | "evaluate";
export interface PieModel {
    /** Identifier to identify the Pie Element in html markup, Must be unique within a pie item config. */
    id: string;
    /** The html Element tag name */
    element: string;
    [x: string]: any;
}
export interface PieContent {
    id: string;
    /**
     * Set of elements to include in the pie, provided in the format `{'element-name': 'mpm-package-name'}`
     */
    elements: PieItemElement;
    pies?: PieDef[];
    aggregatePies?: PieDef[];
    /** Models for each PIE included in the item */
    models: PieModel[];
    markup?: string;
    bundle?: BundleInfo;
}
export declare type PieDef = {
    modules?: PieModulesDef;
    elements?: PieElementsDef;
    name?: string;
    package?: string;
    tag: string;
    aggregatorTag?: string;
    modelElementName?: string;
    blackListed: boolean;
};
export declare type PieModulesDef = {
    controller?: string;
    [x: string]: string;
};
export declare type PieElementsDef = {
    config?: string;
    render: string;
    [x: string]: string;
};
export declare type BundleInfo = {
    url: string;
    hash: string;
};
export declare type ItemSession = {
    id: string;
    data: any[];
};
export interface PieItemElement {
    [elementName: string]: string;
}
interface AdvancedItemConfig {
    id: string;
    pie: PieContent;
    stimulus?: PieContent;
    instructorResources?: [PieContent];
}
export declare type ItemConfig = PieContent | AdvancedItemConfig;
export {};
